////////////////////////////////////////////////////////////////////////////
// mdiedit.cpp   Source for the program MENUDECR.EXE
//
// Sample program using TMenuDescr and Accelerator resources
//
// OWL Menu Descriptors and the TMenuDescr class are best described
// in Ian Spencer's book Teach Yourself OWL Programming in 21 Days,
// Sam's Publishing, Chapter 13, Multiple Document Interface.  Don't
// bother to do without it!  (Thanks Ian)
//
// Written by George Cross, March 26 1996
// Borland C++ Tech Support
// Compiler : Borland C++ 5.0 but is valid for OWL 2.x and above.
////////////////////////////////////////////////////////////////////////////

#include <owl/pch.h>
#include <owl/edit.h>
#include "mdiedit.rh"

////////////////////////////////////////////////////////////////////////////
// TDerivedMDIChild
// This class administers the frame window portion of MDICHILD windows
// In this class the Copy and Paste commands are received and directed
// to the child window.
//
// Command handlers can also reside in the frame for the MDICLIENT, but
// I implemented them here, in the MDICHILD class because I think it is
// easier to understand.
///////////////////////////////////////////////////////////////////////////
class TDerivedMDIChild : public TMDIChild {
public:
	 TDerivedMDIChild(TMDIClient& parent,              //Constructor
					 const char far* title,
					 TWindow* client)
					 : TMDIChild(parent, title, client){}
	 void Paste();                                     //User selected Paste
	 void Copy();                                      //User selected Copy
DECLARE_RESPONSE_TABLE(TDerivedMDIChild);
};
DEFINE_RESPONSE_TABLE1(TDerivedMDIChild,TMDIChild)
  EV_COMMAND(CM_POPUPITEM1,Copy),
  EV_COMMAND(CM_POPUPITEM2,Paste),
END_RESPONSE_TABLE;

//--------------------------------------------------------------------------
// TDerivedMDIChild::Paste
// This function instructs the client to handle the Paste command
// Note that because GetClientWindow returns a TWindow pointer, the
// dynamic_cast function must be used.
//--------------------------------------------------------------------------
void TDerivedMDIChild::Paste(){
	(dynamic_cast<TEdit*>(GetClientWindow()))->HandleMessage(WM_PASTE);
}

//--------------------------------------------------------------------------
// TDerivedMDIChild::Copy
// This function instructs the client to handle the Copy command
// Note that because GetClientWindow returns a TWindow pointer, the
// dynamic_cast function must be used.
//--------------------------------------------------------------------------
void TDerivedMDIChild::Copy(){
	(dynamic_cast<TEdit*>(GetClientWindow()))->HandleMessage(WM_COPY);
}


////////////////////////////////////////////////////////////////////////////
// TDerivedMDIClient
// This class administers the frame window portion of MDICLIENT window
////////////////////////////////////////////////////////////////////////////
class TDerivedMDIClient : public TMDIClient
  {
public:
	 TMDIChild* InitChild();                 //Called when user selects
};                                          //File|New

//--------------------------------------------------------------------------
// TDerivedMDIChild::InitChild
// This function creates the object which administers the MDICHILD windows'
// frame and client.  At this time, the MDICHILD frame is assigned a
// menu descriptor and accelerator table.
//--------------------------------------------------------------------------
TMDIChild* TDerivedMDIClient::InitChild(){

	//
	//Create the child object
	//
	TDerivedMDIChild* child =
		 new TDerivedMDIChild(*this,
									 NULL,
									 new TEdit(0,-1,"",0,0,0,0,TRUE));

	//
	//Attach accelerator table and menu descriptor
	//
	child->Attr.AccelTable = ACCEL_1;
	child->SetMenuDescr(TMenuDescr(MENU_2,0,1,0,0,0,0));
	return child;
}                                           //End InitChild()

////////////////////////////////////////////////////////////////////////////
// Following is the Application object and OwlMain
////////////////////////////////////////////////////////////////////////////
class MDIHelloApp : public TApplication
{
	 protected:
		void InitMainWindow()                 //Set up the app's main window
		  {
			 MainWindow =                                //Create main window
				 new TMDIFrame(NULL,                      //title
									IDM_MDIMENU,               //menu
									*new TDerivedMDIClient()); //client window

			 //
			 //Assign the menu descriptor
			 //
			 MainWindow->SetMenuDescr(TMenuDescr(IDM_MDIMENU,1,0,0,0,1,0));
		  }
};
int OwlMain(int,char*[])
  {
	 return MDIHelloApp().Run();
  }


